import { RegionType } from '@tencent-serverless-framework/common';

/** Vpc 配置 */
export interface PostgresqlVpcConfig {
  /** vpc 的 id */
  vpcId: string;
  /** vpc 子网的 id */
  subnetId: string;
}

/** Postgres 连接 URL */
export interface PostgresqlUrl {
  /** 数据库连接串 */
  connectionString: string;
  /** 数据库主机（地址） */
  host?: string;
  /** 数据库端口 */
  port: number;
  /** 数据库用户名 */
  user: string;
  /** 数据库密码 */
  password: string;
  /** 数据库名 */
  dbname: string;
}

/** Postgresql 部署输入 */
export interface PostgresqlDeployInputs {
  /** 地域 */
  region?: RegionType;
  /** 可用区 */
  zone?: string;
  /** 项目集 Id */
  projectId?: number;
  /** 数据库实例名称 */
  dBInstanceName?: string;
  /** 数据库版本 */
  dBVersion?: string;
  /** 数据库字符集 */
  dBCharset?: string;
  /** 是否启用外网访问 */
  extranetAccess?: boolean;
  /** Vpc 配置 */
  vpcConfig?: PostgresqlVpcConfig;
}

/**  */
export interface PostgresqlDeployOutputs {
  /** 地域 */
  region?: RegionType;
  /** 可用区 */
  zone?: string;
  /** 实例名称 */
  dBInstanceName?: string;
  /** 实例 Id */
  dBInstanceId?: string;
  /** 内网访问 Url 对象 */
  private?: PostgresqlUrl;
  /** 外网访问 Url 对象 */
  public?: PostgresqlUrl;

  /** Vpc 配置 */
  vpcConfig?: PostgresqlVpcConfig;
}

/** 移除 Postgresql 实例 */
export interface PostgresqlRemoveInputs {
  /** 实例名称 */
  dBInstanceName?: string;
}
